@@ -29,7 +29,10 @@ our @EXPORT = qw(
 our @ISA = qw(Exporter);
 
 # Set the package version. 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
+
+# Load the Perl modules.
+use POSIX qw(ttyname);
 
 # Use inline C code.
 use Inline 'C';
@@ -138,17 +141,21 @@ sub search_brackets {
 # Subroutine read_file                                                         #
 #                                                                              #
 # Description:                                                                 #
-# Read file in one piece.                                                      #
+# Read a file in one chunk. The retrieved content is stored in a string        #
+# variable.                                                                    #
+#                                                                              #
+# @argument: $_[0]     filename      (scalar)                                  #
+# @return:   $content  file content  (scalar)                                  #
 #------------------------------------------------------------------------------# 
 sub read_file {
     # Assign the function argument to the local variable.  
     my $file = $_[0];
-    # Open file handler for reading.
+    # Open a file handler for reading.
     open(my $fh, "<", $file);
-    # Read complete content from file.
-    my $content = do { local $/; <$fh> };
-    # Close file handler.
-    close $fh;
+    # Read the complete content from the file.
+    my $content = do {local $/; <$fh>};
+    # Close the file handler.
+    close($fh);
     # Return the file content.
     return $content;
 };
@@ -231,20 +238,24 @@ sub get_ppid {
 };
 
 #------------------------------------------------------------------------------# 
-# Subroutine get_terminal                                                      #
+# Subroutine terminal_command_line                                             #
 #                                                                              #
 # Description:                                                                 #
-# Get terminal process.                                                        #
+# Use the Linux command ps to get the command line of the process which is     #
+# related to the terminal in use.                                              #
+#                                                                              #
+# @argument  $_[0]      PPID          (scalar)                                 #
+# @return    $termproc  command line  (scalar)                                 #
 #------------------------------------------------------------------------------# 
-sub get_terminal {
+sub terminal_command_line {
     # Assign the subroutine argument to the local variable $ppid.
     my $ppid = $_[0];
-    # Get the command column from process.
-    my $terminal = `ps --no-headers -o cmd:1 -p $ppid 2>/dev/null`;
-    # Trim the terminal variable.  
-    $terminal = trim($terminal);
-    # Return terminal.
-    return $terminal
+    # Get the command column from the ps output.
+    my $termproc = `ps --no-headers -o cmd:1 -p $ppid 2>/dev/null`;
+    # Trim the command line output string.  
+    $termproc = trim($termproc);
+    # Return the process related to the terminal in use.
+    return $termproc
 };
 
 #------------------------------------------------------------------------------# 
@@ -275,14 +286,17 @@ sub user_shell {
 # Subroutine user_term                                                         #
 #                                                                              #
 # Description:                                                                 #
-# Get user terminal.                                                           #
+# Get the pseudo terminal slave, which is related to the executed Perl script. #
 #------------------------------------------------------------------------------# 
 sub user_term {
     # Assign the subroutine argument to the local variable $content.
     my @match = @{$_[0]};
+    # Declare the array @result.
     my @result;
     # Get the terminal path.
-    my $term_path = TermPath();
+    #my $term_path = TermPath();
+    my $fileno = fileno(STDIN);
+    my $term_path = ttyname($fileno);
     my ($term) = $term_path =~ /^.*\/dev\/(pts\/\d+)$/;
     if (!defined $term) {
         return ();
@@ -296,6 +310,7 @@ sub user_term {
         $shell = search_brackets($shell);
         my $process = `ps aux | grep $shell | grep $user | grep $term`;
         if ($process ne '') {
+            # Add process to array @result.
             push(@result, $process);
         };
     };
@@ -330,7 +345,7 @@ sub process_command_line {
         # Get the PPID from the command ps.
         my $ppid = get_ppid($pid);
         # Get the terminal in use from the command ps.
-        $terminal = get_terminal($ppid);
+        $terminal = terminal_command_line($ppid);
     } else {
         # Set variable $terminal to NONE.
         $terminal = "NONE";
@@ -448,88 +463,141 @@ Terminal::Identify - Perl extension for identifying the terminal emulator
 
 =head1 SYNOPSIS
 
-  # Standard usage of the Perl command use.
-  use Terminal::Identify;
+Use the package like this
 
-  # Optional usage of the Perl command use.
-  use Terminal::Identify qw(whichterminalami);
+  use Terminal::Identify;                       # Exports all methods
+  use Terminal::Identify qw(whichterminalami);  # Exports method whichterminalami()
 
-  # Standard way for the identification of the terminal emulator.
-  whichterminalami(["PROC"|"PATH"|"FTN"]);
+  # Identify the terminal emulator in use.
+  whichterminalami(["PROC"|"PATH"|"FTN"]);                      # Standard method call   
+  Terminal::Identify::whichterminalami(["PROC"|"PATH"|"FTN"]);  # Alternate method call
 
-  # Alternate way for the identification of the terminal emulator.
-  Terminal::Identify::whichterminalami(["PROC"|"PATH"|"FTN"]);
+or like this
 
-The strings in square brackets are optional. Without subroutine argument the
-process name of the terminal is identified. The key words are separated by
-a logical or. They are controlling the format of the output of the identified
-terminal.
+  use Terminal::Identify;                       # Exports all methods
+  use Terminal::Identify qw(whichterminalami);  # Exports method whichterminalami()
 
-  # Standard usage of the global output format flag.
-  $OutputFormat = "PROC"|"PATH"|"FTN"
+  # Set the global output format flag of the package.
+  $OutputFormat = ["PROC"|"PATH"|"FTN"];
+  $Terminal::Identify::OutputFormat = ["PROC"|"PATH"|"FTN"];
 
-  # Optional usage of the global output format flag.
-  $Terminal::Identify::OutputFormat = "PROC"|"PATH"|"FTN"
+  # Identify the terminal emulator in use.
+  whichterminalami();                      # Standard method call
+  Terminal::Identify::whichterminalami() ; # Alternate method call
 
-The introduced global package variable can also be used for controlling the
-format of the output of the identified terminal. If the global variable is 
-used, the subroutine arguments are ignored.
+=head1 USAGE
+
+The string arguments in the method call in square brackets are optional.
+Without a subroutine argument the process name of the terminal is simply
+identified. The valid method arguments are separated by a logical or. These
+arguments are controlling the format of the output of the identified terminal.
+
+In addition to the method arguments, a global package variable can be used 
+to control the format of the output of the identified terminal. If the global
+package variable is set, the method arguments are ignored if existing in the 
+method call.
 
 =head1 DESCRIPTION
 
 The main objective of this package is to provide a method which is capable of
 identifying the terminal emulator a logged-in user is actual using. 
 
-The logged-in user is related to a login shell. Knowing this, the logged-in
-user as well as the login shell of the logged-in user are determined. Next
-the terminal path to the pseudo terminal shell is identified. Based on this
-informations the related process of logged in user, his login shell and the
-terminal path is identified. The evaluation of the PPID of this process results
-in the parents process ID. The command related to this PID is the name of the
-terminal in use.   
+The logged-in user is related to a valid login shell. Knowing this, the
+logged-in user as well as the login shell of the logged-in user are determined.
+Next the terminal path to the pseudo terminal slave (pts) is identified. Based
+on this informations the related process of the logged-in user, the login shell
+and the terminal path is determined. The evaluation of the PID of the process of
+the running Perl script results in the PPID. The command related to this PPID
+is the name of the terminal emulator in use. Not only a terminal emulator can be
+identified by this package, it is also able to detect if a system console is being
+used by a logged-in user. The package also works if different terminal emulators
+are used and when they were spawned from on initial started terminal emulator.
 
 The terminal emulator in use by the logged-in user can be identified by the
 main command C<whichterminalami> and the other defined aliases.
 
-Not only a terminal emulator can be identified by this package, it is also able
-to detect that a system console is being used by a logged-in user.
-
 =head1 OUTPUT FORMAT
 
+The output format of the identified terminal can be influenced by the subroutine
+arguments C<"PROC">, C<"PATH"> and C<"FTN">.
+
 =over 4 
 
-=item * PROC
+=item * "PROC"
 
-=item * PATH
+  PROC => Full process of the terminal emulator in use. 
 
-=item * FTN
+=item * "PATH"
+
+  PATH => Path to the location of the terminal emulator in use.
+
+=item * "FTN"
+
+  FTN => Friendly terminal name of the terminal emulator in use.
 
 =back
 
 =head1 EXAMPLES
 
+=head2 Example 1
+  
+  # Load the Perl module.
+  use Terminal::Identify;
+
   # Declare the terminal variable.
   my $terminal;
 
-  # Subroutine call without argument.
+  # Method call without an argument.
   $terminal = whichterminalami();
   print $terminal . "\n";
 
-  # Subroutine call with argument "PROC".
+  # Method call with argument "PROC".
   $terminal = whichterminalami("PROC");
   print $terminal . "\n";
 
-  # Subroutine call with argument "PATH".
+  # Method call with argument "PATH".
   $terminal = whichterminalami("PATH"); 
   print $terminal . "\n";
 
-  # Subroutine call with argument "FTN".
+  # Method call with argument "FTN".
   $terminal = whichterminalami("FTN");
   print $terminal . "\n";
 
-=head1 VARIABLES EXPLANATION
+=head2 Example 2
+  
+  # Load the Perl module.
+  use Terminal::Identify;
 
-No variables yet
+  # Declare the terminal variable.
+  my $terminal;
+
+  # Reset the global output format flag.
+  $OutputFormat = "";
+
+  # Method call without an argument.
+  $terminal = whichterminalami();
+  print $terminal . "\n";
+
+  # Set the global output format flag.
+  $OutputFormat = "PROC";
+
+  # Method call without an argument.
+  $terminal = whichterminalami();
+  print $terminal . "\n";
+
+  # Set the global output format flag.
+  $OutputFormat = "PATH";
+
+  # Method call without an argument.
+  $terminal = whichterminalami();
+  print $terminal . "\n";
+
+  # Set the global output format flag.
+  $OutputFormat = "FTN";
+
+  # Method call without an argument.
+  $terminal = whichterminalami();
+  print $terminal . "\n";
 
 =head1 ERROR CODES
 
@@ -541,11 +609,13 @@ No notes yet
 
 =head1 SYSTEM COMPATIBILITY
 
-The module should work on B<Linux> maybe on B<Unix> or B<Unix-like>
+The module should work on B<Linux> and on B<Unix> or B<Unix-like>
 operating systems in general until something else was shown.
 
 =head1 FUNCTIONALITY REQUIREMENT
 
+Following Linux commands should be available for functionality:
+
 =over 4 
 
 =item * ps
@@ -558,6 +628,8 @@ operating systems in general until something else was shown.
 
 =item * which
 
+=item * grep
+
 =back
 
 =head1 METHOD ALIASES
@@ -620,11 +692,16 @@ Terminal emulators tested so far with the package:
 
 =head1 LIMITATIONS
 
-Not known yet
+The limitations of the package are given by the Linux commands and the Linux
+system files which are used by the package. The Linux command C<ps>, the Linux
+command C<users> and the Linux command C<which> must be available. The Linux
+system files C</etc/shells> and C</etc/passwd> must be exist.
 
 =head1 OPEN ISSUES
 
-None so far
+Problems were found with the use of the Inline C module. The problem is caused
+by user and root rights. Until this issue is resolved, the POSIX module is used
+instead of the C code.   
 
 =head1 KNOWN BUGS
 
@@ -635,8 +712,8 @@ Not known yet
 The module identifies the terminal emulator which the logged-in user is using
 currently. For this purpose, the login shells and the logged-in users are
 determined. The Perl script from which we identify the terminal emulator itself
-runs in a pseudo terminal shell (pts) with its own identification number. This
-pseudo terminal shell (pts) is identified, too. Based on all the former
+runs in a pseudo terminal slave (pts) with its own identification number. This
+pseudo terminal slave (pts) is identified, too. Based on all the former
 informations, the terminal emulator in use can be determined. If the Perl script
 runs from within the system console, the output returns the system console. 
 
@@ -652,6 +729,8 @@ ps(1) - Linux manual page
 
 which(1) - Linux manual page
 
+grep(1) - Linux manual page
+
 =head1 AUTHOR
 
 Dr. Peter Netz, E<lt>ztenretep@cpan.orgE<gt>
